@@ -63,7 +63,10 @@ persimon <- function(M1 = 5, S1 = 1, M2 = 5, S2 = 1, M3 = 5, S3 = 1,
 
     # Generate normal or skew normal data
     generate_data <- function(n, mean, sd, skew) {
-      if (is.null(skew)) {
+      if (is.null(skew) || skew == 0) {
+        if(!is.null(skew)){
+          warning("Using stats::rnorm() instead of fGarch::rsnorm() since skew = 0")
+        }
         stats::rnorm(n, mean, sd)
       } else {
         fGarch::rsnorm(n, mean, sd, xi = skew)
